@@ -127,9 +127,11 @@ class products_containing_specific_component_query:
         "component_type",
         "strict_name_search",
         "affect_mode",
+        "search_latest",
         "search_all",
         "search_related_url",
         "search_community",
+        "search_upstreams",
     ]
 
     def __init__(self, params: dict) -> None:
@@ -188,6 +190,8 @@ class products_containing_component_query:
         if self.component_type:
             cond["type"] = self.component_type
 
+        url: str = f"{CORGI_API_URL}/api/v1/components"
+
         results = []
         if self.search_latest:
             result = self.corgi_session.components.retrieve_list(**cond, limit=1000)
@@ -203,7 +207,7 @@ class products_containing_component_query:
             if self.component_type:
                 params["type"] = self.component_type
             related_url_search = requests.get(
-                f"{CORGI_API_URL}/api/v1/components",
+                url,
                 params=params,
             )
 
@@ -256,9 +260,8 @@ class products_containing_component_query:
 
             if self.component_type:
                 params["type"] = self.component_type
-
             related_url_search = requests.get(
-                f"{CORGI_API_URL}/api/v1/components",
+                url,
                 params=params,
             )
 
@@ -309,7 +312,7 @@ class products_containing_component_query:
             if self.component_type:
                 params["type"] = self.component_type
             related_url_search = requests.get(
-                f"{CORGI_API_URL}/api/v1/components",
+                url,
                 params=params,
             )
 
